@@ -29,7 +29,11 @@ from jsw_nx.rubify.to_s import to_s
 
 # next packages
 from jsw_nx.packages.days import days
+from jsw_nx.packages.param import param
+from jsw_nx.packages.qs import qs
 from jsw_nx.packages.tmpl import tmpl
+from jsw_nx.packages.deep_each import deep_each
+
 
 # next classes
 from jsw_nx.classes.date import Date
